@@ -31,18 +31,19 @@ namespace SparkleLib {
         public delegate void StartedEventHandler ();
         public delegate void FinishedEventHandler ();
         public delegate void FailedEventHandler ();
+        public delegate void ProgressChangedEventHandler (double percentage);
 
         public event StartedEventHandler Started;
         public event FinishedEventHandler Finished;
         public event FailedEventHandler Failed;
+        public event ProgressChangedEventHandler ProgressChanged;
 
         protected string target_folder;
         protected string remote_url;
+
         private Thread thread;
 
-        public abstract bool Fetch ();
-
-
+        
         public SparkleFetcherBase (string server, string remote_folder, string target_folder)
         {
             this.target_folder = target_folder;
@@ -50,6 +51,9 @@ namespace SparkleLib {
         }
 
 
+        public abstract bool Fetch ();
+
+
         // Clones the remote repository
         public void Start ()
         {
@@ -95,6 +99,13 @@ namespace SparkleLib {
         }
 
 
+        public virtual void Stop ()
+        {
+            this.thread.Abort ();
+            this.thread.Join ();
+        }
+
+
         public string RemoteUrl {
             get {
                 return this.remote_url;
@@ -110,7 +121,13 @@ namespace SparkleLib {
             }
         }
 
-
+        
+        protected void OnProgressChanged (double percentage) {
+            if (ProgressChanged != null)
+                ProgressChanged (percentage);    
+        }
+    
+        
         private void DisableHostKeyCheckingForHost (string host)
         {
             string path = SparkleConfig.DefaultConfig.HomePath;
@@ -123,8 +140,10 @@ namespace SparkleLib {
 
             string ssh_config_path      = Path.Combine (path, ".ssh");
             string ssh_config_file_path = SparkleHelpers.CombineMore (path, ".ssh", "config");
-            string ssh_config           = Environment.NewLine + "Host " + host +
-                                          Environment.NewLine + "\tStrictHostKeyChecking no";
+            string ssh_config           = Environment.NewLine + "# <SparkleShare>" +
+                                          Environment.NewLine + "Host " + host +
+                                          Environment.NewLine + "\tStrictHostKeyChecking no" +
+                                          Environment.NewLine + "# </SparkleShare>";
 
             if (!Directory.Exists (ssh_config_path))
                 Directory.CreateDirectory (ssh_config_path);
@@ -135,16 +154,14 @@ namespace SparkleLib {
                 writer.Close ();
 
             } else {
-                TextWriter writer = new StreamWriter (ssh_config_file_path);
-                writer.WriteLine (ssh_config);
-                writer.Close ();
+                File.WriteAllText (ssh_config_file_path, ssh_config);
             }
 
             UnixFileSystemInfo file_info = new UnixFileInfo (ssh_config_file_path);
             file_info.FileAccessPermissions = (FileAccessPermissions.UserRead |
                                                FileAccessPermissions.UserWrite);
 
-            SparkleHelpers.DebugInfo ("Fetcher", "Disabled host key checking");
+            SparkleHelpers.DebugInfo ("Fetcher", "Disabled host key checking " + host);
         }
         
 
@@ -159,25 +176,37 @@ namespace SparkleLib {
             }
 
             string ssh_config_file_path = SparkleHelpers.CombineMore (path, ".ssh", "config");
-            string ssh_config           = Environment.NewLine + "Host " + host +
-                                          Environment.NewLine + "\tStrictHostKeyChecking no";
 
             if (File.Exists (ssh_config_file_path)) {
-                StreamReader reader = new StreamReader (ssh_config_file_path);
-                string current_ssh_config = reader.ReadToEnd ();
-                reader.Close ();
+                string current_ssh_config = File.ReadAllText (ssh_config_file_path);
 
-                current_ssh_config = current_ssh_config.Remove (
-                    current_ssh_config.IndexOf (ssh_config), ssh_config.Length);
+                current_ssh_config = current_ssh_config.Trim ();
+                string [] lines = current_ssh_config.Split (Environment.NewLine.ToCharArray ());
+                string new_ssh_config = "";
+                bool in_sparkleshare_section = false;
 
-                bool has_some_ssh_config = new Regex (@"[a-z]").IsMatch (current_ssh_config);
-                if (!has_some_ssh_config) {
+                foreach (string line in lines) {
+                    if (line.StartsWith ("# <SparkleShare>")) {
+                        in_sparkleshare_section = true;
+                        continue;
+                    }
+
+                    if (line.StartsWith ("# </SparkleShare>")) {
+                        in_sparkleshare_section = false;
+                        continue;
+                    }
+
+                    if (in_sparkleshare_section)
+                        continue;
+
+                    new_ssh_config += line + Environment.NewLine;
+                }
+
+                if (string.IsNullOrEmpty (new_ssh_config.Trim ())) {
                     File.Delete (ssh_config_file_path);
 
                 } else {
-                    TextWriter writer = new StreamWriter (ssh_config_file_path);
-                    writer.WriteLine (current_ssh_config);
-                    writer.Close ();
+                    File.WriteAllText (ssh_config_file_path, new_ssh_config.Trim ());
 
                     UnixFileSystemInfo file_info = new UnixFileInfo (ssh_config_file_path);
                     file_info.FileAccessPermissions = (FileAccessPermissions.UserRead |
@@ -185,7 +214,7 @@ namespace SparkleLib {
                 }
             }
 
-            SparkleHelpers.DebugInfo ("Fetcher", "Enabled host key checking");
+            SparkleHelpers.DebugInfo ("Fetcher", "Enabled host key checking for " + host);
         }
 
 
