@@ -29,6 +29,8 @@ namespace SparkleLib {
         private Thread thread;
         private IrcClient client;
         private string nick;
+        private string announcements_password;
+        private bool allow_passwordless_join;
 
 
         public SparkleListenerIrc (Uri server, string folder_identifier) :
@@ -41,6 +43,18 @@ namespace SparkleLib {
             // with a number, so prefix an alphabetic character
             this.nick = "s" + this.nick.Substring (0, 7);
 
+            // Optional password to make the channel access more safe
+            this.announcements_password =
+                SparkleConfig.DefaultConfig.GetConfigOption ("announcements_password");
+
+            // Option to allow access to channel when no password is defined
+            try {
+                string option = SparkleConfig.DefaultConfig.GetConfigOption ("allow_passwordless_join");
+                this.allow_passwordless_join = (option == null || Convert.ToBoolean (option));
+            } catch (Exception) {
+                this.allow_passwordless_join = true;
+            }
+
             base.channels.Add ("#" + folder_identifier);
 
             this.client = new IrcClient () {
@@ -48,6 +62,18 @@ namespace SparkleLib {
                 PingInterval = 60
             };
 
+            string proxy  = Environment.GetEnvironmentVariable ("http_proxy");
+            Uri proxy_uri = null;
+            if (!String.IsNullOrEmpty (proxy) &&
+                Uri.TryCreate (proxy, UriKind.Absolute, out proxy_uri)) {
+
+                if (proxy_uri.Scheme == "http") {
+                    this.client.ProxyType = ProxyType.Http;
+                    this.client.ProxyHost = proxy_uri.Host;
+                    this.client.ProxyPort = proxy_uri.Port;
+                }
+            }
+
             this.client.OnConnected += delegate {
                 base.is_connecting = false;
                 OnConnected ();
@@ -90,13 +116,35 @@ namespace SparkleLib {
                     try {
                         // Connect, login, and join the channel
                         int port = base.server.Port;
-                        if (port < 0) port = 6667;
+
+                        if (port < 0)
+                            port = 6667;
+
                         this.client.Connect (base.server.Host, port);
-                        this.client.Login (this.nick, this.nick);
+                        this.client.Login (this.nick, this.nick, 8, this.nick);
 
                         foreach (string channel in base.channels) {
                             SparkleHelpers.DebugInfo ("ListenerIrc", "Joining channel " + channel);
-                            this.client.RfcJoin (channel);
+
+                            if (!string.IsNullOrEmpty (this.announcements_password)) {
+                                SparkleHelpers.DebugInfo ("ListenerIrc", "Password set to access the channel");
+                                this.client.RfcJoin (channel, this.announcements_password);
+                                this.client.RfcMode (channel, "+k " + this.announcements_password);
+
+                            } else {
+                                if (this.allow_passwordless_join) {
+                                    SparkleHelpers.DebugInfo ("ListenerIrc", "Accessing unprotected channel, change the setting to not access");
+                                    this.client.RfcJoin (channel);
+                                
+                                } else {
+                                    SparkleHelpers.DebugInfo ("ListenerIrc", "Unprotected channel, change the setting to access");
+                                    base.is_connecting = false;
+                                    OnDisconnected ();
+                                    throw new ConnectionException ("Unprotected channel, change the setting to access");
+                                }
+                            }
+
+                            this.client.RfcMode (channel, "+s");
                         }
 
                         // List to the channel, this blocks the thread
@@ -123,7 +171,19 @@ namespace SparkleLib {
 
                 if (IsConnected) {
                     SparkleHelpers.DebugInfo ("ListenerIrc", "Joining channel " + channel);
-                    this.client.RfcJoin (channel);
+                    if (this.announcements_password != null) {
+                        SparkleHelpers.DebugInfo ("ListenerIrc", "Password set to access the channel");
+                        this.client.RfcJoin (channel, this.announcements_password);
+                        this.client.RfcMode (channel, "+k " + this.announcements_password);
+                    } else {
+                        if (allow_passwordless_join) {
+                            SparkleHelpers.DebugInfo ("ListenerIrc", "Accessing a dangerous channel change the setting to not access");
+                            this.client.RfcJoin (channel);
+                        } else {
+                            SparkleHelpers.DebugInfo ("ListenerIrc", "Dangerous channel, change the setting to access");
+                        }
+                    }
+                    this.client.RfcMode (channel, "+s");
                 }
             }
         }
